@@ -1,2 +1,2 @@
-__all__ = ['dbintf',]
-from .dbintf import dbintf
+__all__ = ['dbintf']
+from .dbintf import dbintf
\ No newline at end of file
